@@ -634,7 +634,8 @@ gconf_settings_backend_gvariant_to_gconf_value (GVariant *value)
 static GVariant *
 gconf_settings_backend_read (GSettingsBackend   *backend,
                              const gchar        *key,
-                             const GVariantType *expected_type)
+                             const GVariantType *expected_type,
+                             gboolean            default_value)
 {
   GConfSettingsBackend *gconf = GCONF_SETTINGS_BACKEND (backend);
   GConfValue *gconf_value;
@@ -664,7 +665,9 @@ gconf_settings_backend_write (GSettingsBackend *backend,
   GConfValue           *gconf_value;
   GError               *error;
 
+  g_variant_ref_sink (value);
   gconf_value = gconf_settings_backend_gvariant_to_gconf_value (value);
+  g_variant_unref (value);
   if (gconf_value == NULL)
     return FALSE;
 
@@ -799,12 +802,19 @@ gconf_settings_backend_get_writable (GSettingsBackend *backend,
                                      const gchar      *name)
 {
   GConfSettingsBackend *gconf = GCONF_SETTINGS_BACKEND (backend);
+  GConfValue *value;
 
   /* We don't support checking writabality for a whole subpath, so we just say
    * it's not writable in such a case. */
   if (name[strlen(name) - 1] == '/')
     return FALSE;
 
+  value = gconf_client_get (gconf->priv->client, name, NULL);
+  if (value == NULL)
+    return TRUE;
+  else
+    gconf_value_free (value);
+
   return gconf_client_key_is_writable (gconf->priv->client, name, NULL);
 }
 
@@ -866,12 +876,6 @@ gconf_settings_backend_unsubscribe (GSettingsBackend *backend,
   g_free (path);
 }
 
-static gboolean
-gconf_settings_backend_supports_context (const gchar *context)
-{
-  return FALSE;
-}
-
 static void
 gconf_settings_backend_finalize (GObject *object)
 {
@@ -924,7 +928,6 @@ gconf_settings_backend_class_init (GConfSettingsBackendClass *class)
   backend_class->get_writable = gconf_settings_backend_get_writable;
   backend_class->subscribe = gconf_settings_backend_subscribe;
   backend_class->unsubscribe = gconf_settings_backend_unsubscribe;
-  backend_class->supports_context = gconf_settings_backend_supports_context;
 
   g_type_class_add_private (class, sizeof (GConfSettingsBackendPrivate));
 }
